API = "http://www.estradas.pt/proxy.ashx?http://arcgis1.estradas.pt/arcgis/rest/services/Estradas/MapaEP/MapServer/1/query?f=json&where=dbtrafego.telematicadata.cctv_url.url%20is%20not%20null&returnGeometry=true&spatialRel=esriSpatialRelIntersects&outFields=dbtrafego.telematicadata.EQUIPAMENTOS_DATEX.id%2Cdbtrafego.telematicadata.EQUIPAMENTOS_DATEX.tipo%2Cdbtrafego.telematicadata.cctv_url.descricao%2Cdbtrafego.telematicadata.cctv_url.url"